from splent_io.splent_feature_auth.models import User
from splent_io.splent_feature_profile.models import UserProfile
from splent_framework.seeders.BaseSeeder import BaseSeeder


class ProfileSeeder(BaseSeeder):
    priority = 2  # After AuthSeeder (priority 1)

    def run(self):
        users = User.query.all()
        names = [("John", "Doe"), ("Jane", "Doe")]

        profiles = []
        for user, (name, surname) in zip(users, names):
            if not user.profile:
                profiles.append(
                    UserProfile(user_id=user.id, name=name, surname=surname)
                )

        if profiles:
            self.seed(profiles)



from splent_framework.hooks.template_hooks import register_template_hook
from flask import render_template, url_for


def sidebar_edit_profile():
    return render_template("hooks/sidebar_edit_profile.html")


def navbar_user_name():
    return render_template("hooks/navbar_user_name.html")


register_template_hook("layout.sidebar.authenticated.items", sidebar_edit_profile)
register_template_hook("layout.navbar.authenticated", navbar_user_name)


# ── Script hooks ─────────────────────────────────────────────────────────────

def profile_scripts():
    return '<script src="' + url_for('profile.assets', subfolder='dist', filename='profile.bundle.js') + '"></script>'


register_template_hook("layout.scripts", profile_scripts)
